@@ -4,7 +4,7 @@ import logging
 import re
 from operator import itemgetter
 
-from streamlink.plugin import Plugin
+from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
 from streamlink.stream import HLSStream
 
@@ -12,15 +12,6 @@ log = logging.getLogger(__name__)
 JSON_VOD_URL = "https://api.arte.tv/api/player/v1/config/{0}/{1}?platform=ARTE_NEXT"
 JSON_LIVE_URL = "https://api.arte.tv/api/player/v1/livestream/{0}"
 
-_url_re = re.compile(r"""
-    https?://(?:\w+\.)?arte\.tv/(?:guide/)?
-    (?P<language>[a-z]{2})/
-    (?:
-        (?:videos/)?(?P<video_id>(?!RC\-|videos)[^/]+?)/.+ | # VOD
-        (?:direct|live)        # Live TV
-    )
-""", re.VERBOSE)
-
 _video_schema = validate.Schema({
     "videoJsonPlayer": {
         "VSR": validate.any(
@@ -39,31 +30,32 @@ _video_schema = validate.Schema({
 })
 
 
+@pluginmatcher(re.compile(r"""
+    https?://(?:\w+\.)?arte\.tv/(?:guide/)?
+    (?P<language>[a-z]{2})/
+    (?:
+        (?:videos/)?(?P<video_id>(?!RC-|videos)[^/]+?)/.+
+        |
+        (?:direct|live)
+    )
+""", re.VERBOSE))
 class ArteTV(Plugin):
-    @classmethod
-    def can_handle_url(cls, url):
-        return _url_re.match(url)
-
     def _create_stream(self, streams):
         variant, variantname = min([(stream["versionProg"], stream["versionLibelle"]) for stream in streams.values()],
                                    key=itemgetter(0))
-        log.debug(u"Using the '{0}' stream variant".format(variantname))
+        log.debug(f"Using the '{variantname}' stream variant")
         for sname, stream in streams.items():
             if stream["versionProg"] == variant:
                 if stream["mediaType"] == "hls":
                     try:
                         streams = HLSStream.parse_variant_playlist(self.session, stream["url"])
-                        for s in streams.items():
-                            yield s
-                    except IOError as err:
-                        log.warning(u"Failed to extract HLS streams for {0}/{1}: {2}".format(sname,
-                                                                                             stream["versionLibelle"],
-                                                                                             err))
+                        yield from streams.items()
+                    except OSError as err:
+                        log.warning(f"Failed to extract HLS streams for {sname}/{stream['versionLibelle']}: {err}")
 
     def _get_streams(self):
-        match = _url_re.match(self.url)
-        language = match.group('language')
-        video_id = match.group('video_id')
+        language = self.match.group('language')
+        video_id = self.match.group('video_id')
         if video_id is None:
             json_url = JSON_LIVE_URL.format(language)
         else:
