@@ -3,7 +3,7 @@ import re
 from html import unescape as html_unescape
 from urllib.parse import unquote_plus, urlencode
 
-from streamlink.plugin import Plugin
+from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api.utils import itertags
 from streamlink.stream import DASHStream, HTTPStream
 from streamlink.utils import parse_json
@@ -11,9 +11,10 @@ from streamlink.utils import parse_json
 log = logging.getLogger(__name__)
 
 
+@pluginmatcher(re.compile(
+    r"https?://(?:www\.)?facebook(?:\.com|corewwwi\.onion)/[^/]+/(?:posts|videos)/(?P<video_id>\d+)"
+))
 class Facebook(Plugin):
-    _url_re = re.compile(r'''(?x)https?://(?:www\.)?facebook(?:\.com|corewwwi.onion)
-        /[^/]+/(?:posts|videos)/(?P<video_id>[0-9]+)''')
     _src_re = re.compile(r'''(sd|hd)_src["']?\s*:\s*(?P<quote>["'])(?P<url>.+?)(?P=quote)''')
     _dash_manifest_re = re.compile(r'''dash_manifest["']?\s*:\s*["'](?P<manifest>.+?)["'],''')
     _playlist_re = re.compile(r'''video:\[({url:".+?}\])''')
@@ -26,10 +27,6 @@ class Facebook(Plugin):
     _DEFAULT_REV = 4681796
     _TAHOE_URL = "https://www.facebook.com/video/tahoe/async/{0}/?chain=true&isvideo=true&payloadtype=primary"
 
-    @classmethod
-    def can_handle_url(cls, url):
-        return cls._url_re.match(url) is not None
-
     def get_title(self):
         res = self.session.http.get(self.url)
         m = self._title_re.search(res.text)
@@ -109,7 +106,7 @@ class Facebook(Plugin):
 
         # fallback to tahoe player url
         log.debug("Falling back to tahoe player")
-        video_id = self._url_re.match(self.url).group("video_id")
+        video_id = self.match.group("video_id")
         url = self._TAHOE_URL.format(video_id)
         data = {
             "__a": 1,
