@@ -1,15 +1,17 @@
 import logging
 import re
 
-from streamlink.plugin import Plugin, PluginError
-from streamlink.stream import HLSStream
+from streamlink.plugin import Plugin, PluginError, pluginmatcher
 from streamlink.plugin.api import validate
+from streamlink.stream import HLSStream
 
 log = logging.getLogger(__name__)
 
 
+@pluginmatcher(re.compile(
+    r"https?://(?:www\.)?ccma\.cat/tv3/directe/(.+?)/"
+))
 class TV3Cat(Plugin):
-    _url_re = re.compile(r"https?://(?:www\.)?ccma\.cat/tv3/directe/(.+?)/")
     _stream_info_url = "http://dinamics.ccma.cat/pvideo/media.jsp" \
                        "?media=video&version=0s&idint={ident}&profile=pc&desplacament=0"
     _media_schema = validate.Schema({
@@ -23,14 +25,9 @@ class TV3Cat(Plugin):
         validate.transform(lambda x: x if isinstance(x, list) else [x])
     )
 
-    @classmethod
-    def can_handle_url(cls, url):
-        return cls._url_re.match(url) is not None
-
     def _get_streams(self):
-        match = self._url_re.match(self.url)
-        if match:
-            ident = match.group(1)
+        if self.match:
+            ident = self.match.group(1)
             data_url = self._stream_info_url.format(ident=ident)
             stream_infos = self.session.http.json(self.session.http.get(data_url), schema=self._channel_schema)
 
