@@ -1,14 +1,11 @@
-from ..exceptions import StreamError
-from streamlink.stream.stream import Stream
-
 from streamlink.stream.akamaihd import AkamaiHDStream
+from streamlink.stream.dash import DASHStream
+from streamlink.stream.flvconcat import extract_flv_header_tags
 from streamlink.stream.hds import HDSStream
 from streamlink.stream.hls import HLSStream
 from streamlink.stream.http import HTTPStream
+from streamlink.stream.playlist import FLVPlaylist, Playlist
 from streamlink.stream.rtmpdump import RTMPStream
-from streamlink.stream.dash import DASHStream
+from streamlink.stream.stream import Stream, StreamIO
 from streamlink.stream.streamprocess import StreamProcess
-from streamlink.stream.wrappers import StreamIOWrapper, StreamIOIterWrapper, StreamIOThreadWrapper
-
-from streamlink.stream.flvconcat import extract_flv_header_tags
-from streamlink.stream.playlist import Playlist, FLVPlaylist
+from streamlink.stream.wrappers import StreamIOIterWrapper, StreamIOThreadWrapper, StreamIOWrapper
